@@ -60,8 +60,7 @@ class PackageTemplate(Package):
                                  version=None, catkin_deps=None, system_deps=None,
                                  boost_comps=None):
         """
-        alternative factory method mapping CLI args to argument for
-        Package class
+        Alternative factory method mapping CLI args to argument for Package class.
 
         :param package_name:
         :param description:
@@ -72,7 +71,7 @@ class PackageTemplate(Package):
         :param catkin_deps:
         """
         # Sort so they are alphebetical
-        licenses = list(licenses or ["TODO"])
+        licenses = list(licenses or ['TODO'])
         licenses.sort()
         if not maintainer_names:
             maintainer_names = [getpass.getuser()]
@@ -105,12 +104,12 @@ class PackageTemplate(Package):
                 buildtool_depends.append(Dependency('genmsg'))
                 continue
             if dep.lower() == 'message_generation':
-                if not 'message_runtime' in catkin_deps:
+                if 'message_runtime' not in catkin_deps:
                     sys.stderr.write('WARNING: Packages with messages or services should depend on both message_generation and message_runtime\n')
                 build_depends.append(Dependency('message_generation'))
                 continue
             if dep.lower() == 'message_runtime':
-                if not 'message_generation' in catkin_deps:
+                if 'message_generation' not in catkin_deps:
                     sys.stderr.write('WARNING: Packages with messages or services should depend on both message_generation and message_runtime\n')
                 exec_depends.append(Dependency('message_runtime'))
                 continue
@@ -120,7 +119,7 @@ class PackageTemplate(Package):
         if boost_comps:
             if not system_deps:
                 system_deps = ['boost']
-            elif not 'boost' in system_deps:
+            elif 'boost' not in system_deps:
                 system_deps.append('boost')
         for dep in system_deps or []:
             if not dep.lower().startswith('python-'):
@@ -156,15 +155,16 @@ def read_template_file(filename, rosdistro):
                 template_contents = fhand.read()
             return template_contents
     raise IOError(
-        "Could not read template for ROS distro "
+        'Could not read template for ROS distro '
         "'{}' at '{}': ".format(rosdistro, ', '.join(templates)) +
-        "no such file or directory"
+        'no such file or directory'
     )
 
 
 def _safe_write_files(newfiles, target_dir):
     """
-    writes file contents to target_dir/filepath for all entries of newfiles.
+    Write file contents to target_dir/filepath for all entries of newfiles.
+
     Aborts early if files exist in places for new files or directories
 
     :param newfiles: a dict {filepath: contents}
@@ -176,7 +176,7 @@ def _safe_write_files(newfiles, target_dir):
         if os.path.exists(target_file):
             raise ValueError('File exists: %s' % target_file)
         dirname = os.path.dirname(target_file)
-        while(dirname != target_dir):
+        while dirname != target_dir:
             if os.path.isfile(dirname):
                 raise ValueError('Cannot create directory, file exists: %s' %
                                  dirname)
@@ -196,7 +196,7 @@ def _safe_write_files(newfiles, target_dir):
 def create_package_files(target_path, package_template, rosdistro,
                          newfiles=None, meta=False):
     """
-    creates several files from templates to start a new package.
+    Create several files from templates to start a new package.
 
     :param target_path: parent folder where to create the package
     :param package_template: contains the required information
@@ -211,7 +211,7 @@ def create_package_files(target_path, package_template, rosdistro,
         newfiles[manifest_path] = \
             create_package_xml(package_template, rosdistro, meta=meta)
     cmake_path = os.path.join(target_path, 'CMakeLists.txt')
-    if not cmake_path in newfiles:
+    if cmake_path not in newfiles:
         newfiles[cmake_path] = create_cmakelists(package_template, rosdistro, meta=meta)
     _safe_write_files(newfiles, target_path)
     if 'roscpp' in package_template.catkin_deps:
@@ -226,21 +226,24 @@ def create_package_files(target_path, package_template, rosdistro,
 
 
 class CatkinTemplate(string.Template):
-    """subclass to use @ instead of $ as markers"""
+    """subclass to use @ instead of $ as markers."""
+
     delimiter = '@'
     escape = '@'
 
 
 def create_cmakelists(package_template, rosdistro, meta=False):
-    """
+    """Create CMake file contents from the template.
+
     :param package_template: contains the required information
     :returns: file contents as string
     """
     if meta:
         template_path = get_metapackage_cmake_template_path()
-        temp_dict = {'name': package_template.name,
-                      'metapackage_arguments': ''
-                      }
+        temp_dict = {
+            'name': package_template.name,
+            'metapackage_arguments': '',
+        }
         return configure_file(template_path, temp_dict)
     else:
         cmakelists_txt_template = read_template_file('CMakeLists.txt', rosdistro)
@@ -314,6 +317,7 @@ def _create_include_macro(package_template):
         result += '\n'.join(includes)
     return result
 
+
 def _create_depend_tag(dep_type,
                        name,
                        version_eq=None,
@@ -321,10 +325,7 @@ def _create_depend_tag(dep_type,
                        version_lte=None,
                        version_gt=None,
                        version_gte=None):
-    """
-    Helper to create xml snippet for package.xml
-    """
-
+    """Create xml snippet for package.xml."""
     version_string = []
     for key, var in {'version_eq': version_eq,
                      'version_lt': version_lt,
@@ -342,6 +343,8 @@ def _create_depend_tag(dep_type,
 
 def create_package_xml(package_template, rosdistro, meta=False):
     """
+    Create package xml file content.
+
     :param package_template: contains the required information
     :returns: file contents as string
     """
@@ -352,10 +355,11 @@ def create_package_xml(package_template, rosdistro, meta=False):
     for key in package_template.__slots__:
         temp_dict[key] = getattr(package_template, key)
 
-    if package_template.version_abi:
-        temp_dict['version_abi'] = ' abi="%s"' % package_template.version_abi
+    if package_template.version_compatibility:
+        temp_dict['version_compatibility'] = \
+            ' compatibility="%s"' % package_template.version_compatibility
     else:
-        temp_dict['version_abi'] = ''
+        temp_dict['version_compatibility'] = ''
 
     if not package_template.description:
         temp_dict['description'] = 'The %s package ...' % package_template.name
@@ -367,7 +371,7 @@ def create_package_xml(package_template, rosdistro, meta=False):
 
     def get_person_tag(tagname, person):
         email_string = (
-            "" if person.email is None else 'email="%s"' % person.email
+            '' if person.email is None else 'email="%s"' % person.email
         )
         return '  <%s %s>%s</%s>\n' % (tagname, email_string,
                                        person.name, tagname)
@@ -379,7 +383,7 @@ def create_package_xml(package_template, rosdistro, meta=False):
 
     urls = []
     for url in package_template.urls:
-        type_string = ("" if url.type is None
+        type_string = ('' if url.type is None
                        else 'type="%s"' % url.type)
         urls.append('    <url %s >%s</url>\n' % (type_string, url.url))
     temp_dict['urls'] = ''.join(urls)
@@ -411,7 +415,7 @@ def create_package_xml(package_template, rosdistro, meta=False):
                     dep.version_lte,
                     dep.version_gt,
                     dep.version_gte
-                    )
+                )
                 dependencies.append(dep_tag)
             else:
                 dependencies.append(_create_depend_tag(dep_type,
