@@ -1,5 +1,6 @@
 from __future__ import print_function
 
+import sys
 import unittest
 
 from mock import Mock
@@ -26,6 +27,9 @@ def create_mock(name, build_depends, run_depends, path):
 
 class TopologicalOrderTest(unittest.TestCase):
 
+    if sys.version_info[0] == 2:
+        assertRaisesRegex = unittest.TestCase.assertRaisesRegexp
+
     def test_topological_order_packages(self):
         mc = create_mock('c', [], [], 'pc')
         md = create_mock('d', [], [], 'pd')
@@ -50,13 +54,12 @@ class TopologicalOrderTest(unittest.TestCase):
         pkg1 = create_mock('pkg', [], [], 'path/to/pkg1')
         pkg2_dep = create_mock('pkg_dep', [], [], 'path/to/pkg2_dep')
         pkg2 = create_mock('pkg', [pkg2_dep], [], 'path/to/pkg2')
-        if hasattr(self, 'assertRaisesRegexp'):
-            with self.assertRaisesRegexp(RuntimeError, 'Two packages with the same name "pkg" in the workspace'):
-                topological_order_packages({
-                    pkg1.path: pkg1,
-                    pkg2_dep.path: pkg2_dep,
-                    pkg2.path: pkg2,
-                })
+        with self.assertRaisesRegex(RuntimeError, 'Two packages with the same name "pkg" in the workspace'):
+            topological_order_packages({
+                pkg1.path: pkg1,
+                pkg2_dep.path: pkg2_dep,
+                pkg2.path: pkg2,
+            })
 
     def test_package_decorator_init(self):
 
